# Retrospective Template

Use this template for sprint retrospectives and team retrospectives.

```markdown
# Sprint [#] Retrospective - [Date]

## Meeting Details
**Date**: [Date]
**Team**: [Team]
**Sprint**: [Sprint dates]
**Facilitator**: [Name]

## Sprint Summary

**Sprint Goal**: [Goal]
**Goal Met**: Yes / Partially / No

**Completed**: [#] points
**Velocity**: [#] points
**Planned**: [#] points

## Pre-Read

**Sprint Metrics**:
- Tasks completed: [#]
- Tasks carried over: [#]
- Bugs found: [#]
- Blockers encountered: [#]

## Discussion

### What Went Well (Keep)

[Team input during meeting]

### What Didn't Go Well (Stop)

[Team input during meeting]

### What To Try (Start)

[Team input during meeting]

### Shout-outs

[Team recognition]

## Action Items

- [ ] [Improvement to implement] - @[Owner] - Due: [Date]
- [ ] [Process change] - @[Owner] - Due: [Date]

## Follow-up

**Review actions in**: [Next retro date]
```

